@@ -1,4 +1,4 @@
-import os
+import sys
 import getpass
 import datetime
 import pathlib
@@ -11,7 +11,7 @@ from ._config_parser import ConfigParser
 
 def write_script(
     args: argparse.Namespace,
-    build_directory: str,
+    build_directory: pathlib.Path,
     template_filename: str,
     output_filename: str,
 ) -> set:
@@ -21,12 +21,13 @@ def write_script(
     configuration["shared_settings"] = config_parser.shared_settings
     configuration["portable"] = args.portable is not None
     configuration["loglevel"] = args.loglevel
-    configuration["config_folder"] = repr(pathlib.Path(args.yaml_file).resolve().parent)
+    configuration["config_folder"] = repr(args.yaml_file.resolve().parent)
 
     configuration["theme_name"] = args.theme
 
     configuration["author"] = getpass.getuser()
     configuration["current_date"] = datetime.date.today().strftime("%Y-%m-%d")
+    configuration["sys_executable"] = sys.executable
 
     template_environment = jinja2.Environment(  # nosec
         loader=jinja2.PackageLoader("webviz_config", "templates"),
@@ -36,7 +37,6 @@ def write_script(
 
     template = template_environment.get_template(template_filename)
 
-    with open(os.path.join(build_directory, output_filename), "w") as filehandle:
-        filehandle.write(template.render(configuration))
+    (build_directory / output_filename).write_text(template.render(configuration))
 
     return config_parser.assets
